<?php
/**
 * A factory class for ProtocolResolver
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class ProtocolResolverFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Returns a singleton (registry-based) ProtocolResolver instance
	 *
	 * @return	$resolverInstance	An instance of a ProtocolResolver class
	 */
	public static final function createResolverFromConfiguredProtocol () {
		// Get the configured protocol
		$protocolName = FrameworkConfiguration::getSelfInstance()->getConfigEntry('hub_communication_protocol_type');

		// If there is no handler?
		if (Registry::getRegistry()->instanceExists($protocolName . '_protocol_resolver')) {
			// Get handler from registry
			$resolverInstance = Registry::getRegistry()->getInstance($protocolName . '_protocol_resolver');
		} else {
			// Get the handler instance
			$resolverInstance = self::createObjectByConfiguredName($protocolName . '_protocol_resolver_class');

			// Add it to the registry
			Registry::getRegistry()->addInstance($protocolName . '_protocol_resolver', $resolverInstance);
		}

		// Return the instance
		return $resolverInstance;
	}
}

// [EOF]
?>
