<?php
/**
 * A factory class for unit sources
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class UnitSourceFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of a configurable and singleton unit source
	 *
	 * @param	$unitType			Type of the unit source
	 * @return	$sourceInstance		A UnitSource class instance
	 */
	public static final function createUnitSourceInstance ($unitType) {
		// Do we have cache?
		if (!Registry::getRegistry()->instanceExists($unitType . '_unit_source')) {
			// Then construct the class' configuraton entry
			$className = '' . $unitType . '_unit_source_class';

			// Get a class from that configuration entry
			$sourceInstance = self::createObjectByConfiguredName($className);

			// Add it to the registry
			Registry::getRegistry()->addInstance($unitType . '_unit_source', $sourceInstance);
		} else {
			// Get it from registry
			$sourceInstance = Registry::getRegistry()->getInstance($unitType . '_unit_source');
		}

		// For any purposes, return the source instance
		return $sourceInstance;
	}
}

// [EOF]
?>
