<?php
/**
 * A Init dht state class
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class DhtInitState extends BaseDhtState implements Stateable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set state name
		$this->setStateName('init');
	}

	/**
	 * Creates an instance of this class
	 *
	 * @param	$dhtInstance	An instance of a Distributable class
	 * @return	$stateInstance	An instance of a Stateable class
	 */
	public final static function createDhtInitState (Distributable $dhtInstance) {
		// Get new instance
		$stateInstance = new DhtInitState();

		// Debug message
		//* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('DHT-STATE[' . __METHOD__ . ':' . __LINE__ . ']: Has changed from ' . $dhtInstance->getPrintableState() . ' to ' . $stateInstance->getStateName() . '.');

		// Set the dht instance
		$stateInstance->setDhtInstance($dhtInstance);

		// Return the prepared instance
		return $stateInstance;
	}

	/**
	 * The DHT has been initialized. This means that the state can be changed
	 * to the next one: virgin.
	 *
	 * @return	void
	 */
	public function dhtHasInitialized () {
		// Create a new instance
		DhtStateFactory::createDhtStateInstanceByName('virgin', $this->getDhtInstance());
	}
}

// [EOF]
?>
